@@ -3,12 +3,14 @@ import pytest
 sa = pytest.importorskip("sqlalchemy")
 
 import os
-import responses
+
 import flask
-from flask_sqlalchemy import SQLAlchemy
-from sqlalchemy import event
+import responses
 from flask_caching import Cache
 from flask_login import LoginManager, UserMixin, current_user, login_user, logout_user
+from flask_sqlalchemy import SQLAlchemy
+from sqlalchemy import event
+
 from flask_dance.consumer import OAuth2ConsumerBlueprint, oauth_authorized, oauth_error
 from flask_dance.consumer.storage.sqla import OAuthConsumerMixin, SQLAlchemyStorage
 
@@ -114,7 +116,10 @@ def test_sqla_storage_without_user(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 2
 
@@ -194,7 +199,10 @@ def test_sqla_storage(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 3
 
@@ -332,7 +340,10 @@ def test_sqla_flask_login(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 4
 
@@ -357,7 +368,10 @@ def test_sqla_flask_login(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 4
 
@@ -702,7 +716,10 @@ def test_sqla_overwrite_token(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 2
 
@@ -747,7 +764,10 @@ def test_sqla_cache(app, db, blueprint, request):
             )
             # check that we redirected the client
             assert resp.status_code == 302
-            assert resp.headers["Location"] == "https://a.b.c/oauth_done"
+            assert resp.headers["Location"] in (
+                "https://a.b.c/oauth_done",
+                "/oauth_done",
+            )
 
     assert len(queries) == 2
 
