@@ -1,19 +1,18 @@
-try:
-    from urllib.parse import quote_plus
-except ImportError:
-    from urllib import quote_plus
-import pytest
 from unittest import mock
-import responses
+from urllib.parse import quote_plus
+
 import flask
+import pytest
+import responses
+from oauthlib.oauth1.rfc5849.utils import parse_authorization_header
 from werkzeug.middleware.proxy_fix import ProxyFix
+
 from flask_dance.consumer import (
     OAuth1ConsumerBlueprint,
     oauth_authorized,
     oauth_before_login,
     oauth_error,
 )
-from oauthlib.oauth1.rfc5849.utils import parse_authorization_header
 from flask_dance.consumer.requests import OAuth1Session
 from flask_dance.consumer.storage import MemoryStorage
 
@@ -137,7 +136,7 @@ def test_authorized_url():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
         # check that we obtained an access token
         assert len(responses.calls) == 1
         assert "Authorization" in responses.calls[0].request.headers
@@ -150,10 +149,11 @@ def test_authorized_url():
         assert auth_header["oauth_token"] == "foobar"
         assert auth_header["oauth_verifier"] == "xyz"
         # check that we stored the access token and secret in the session
-        assert flask.session["test-service_oauth_token"] == {
-            "oauth_token": "xxx",
-            "oauth_token_secret": "yyy",
-        }
+        with client.session_transaction() as sess:
+            assert sess["test-service_oauth_token"] == {
+                "oauth_token": "xxx",
+                "oauth_token_secret": "yyy",
+            }
 
 
 @responses.activate
@@ -221,7 +221,7 @@ def test_redirect_to():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/blargl"
+        assert resp.headers["Location"] in ("https://a.b.c/blargl", "/blargl")
 
 
 @responses.activate
@@ -252,7 +252,7 @@ def test_redirect_fallback():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
 
 
 def test_authorization_required_decorator_allowed():
@@ -286,7 +286,10 @@ def test_authorization_required_decorator_redirect():
         resp = client.get("/restricted", base_url="https://a.b.c")
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/login/test-service"
+        assert resp.headers["Location"] in (
+            "https://a.b.c/login/test-service",
+            "/login/test-service",
+        )
 
 
 @requires_blinker
@@ -556,3 +559,28 @@ def test_custom_session_class():
     )
     assert isinstance(bp.session, CustomOAuth1Session)
     assert bp.session.my_attr == "foobar"
+
+
+def test_rule_kwargs():
+    blueprint = OAuth1ConsumerBlueprint(
+        "test-service",
+        __name__,
+        client_key="client_key",
+        client_secret="client_secret",
+        base_url="https://example.com",
+        request_token_url="https://example.com/oauth/request_token",
+        access_token_url="https://example.com/oauth/access_token",
+        authorization_url="https://example.com/oauth/authorize",
+        redirect_to="my_view",
+        rule_kwargs={"host": "example2.com"},
+    )
+    app = flask.Flask(__name__)
+    app.secret_key = "secret"
+    app.register_blueprint(blueprint, url_prefix="/login")
+    rules = [
+        rule
+        for rule in app.url_map.iter_rules()
+        if rule.endpoint.startswith("test-service.")
+    ]
+    assert all(rule.host == "example2.com" for rule in rules)
+    assert len(rules) == 2
