@@ -1,19 +1,16 @@
 import json
 import re
-from oauthlib.oauth2 import MissingCodeError
-
-try:
-    from urllib.parse import quote_plus, parse_qsl
-except ImportError:
-    from urllib import quote_plus
-    from urlparse import parse_qsl
-import pytest
 from unittest import mock
-import responses
-from urlobject import URLObject
+from urllib.parse import parse_qsl
+
 import flask
+import pytest
+import responses
 from freezegun import freeze_time
+from oauthlib.oauth2 import MissingCodeError
+from urlobject import URLObject
 from werkzeug.middleware.proxy_fix import ProxyFix
+
 from flask_dance.consumer import (
     OAuth2ConsumerBlueprint,
     oauth_authorized,
@@ -78,7 +75,8 @@ def test_login_url():
             "/login/test-service", base_url="https://a.b.c", follow_redirects=False
         )
         # check that we saved the state in the session
-        assert flask.session["test-service_oauth_state"] == "random-string"
+        with client.session_transaction() as sess:
+            assert sess["test-service_oauth_state"] == "random-string"
     # check that we redirected the client
     assert resp.status_code == 302
     location = URLObject(resp.headers["Location"])
@@ -131,7 +129,7 @@ def test_authorized_url():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
         # check that we obtained an access token
         assert len(responses.calls) == 1
         request_data = dict(parse_qsl(responses.calls[0].request.body))
@@ -140,11 +138,12 @@ def test_authorized_url():
             == "https://a.b.c/login/test-service/authorized"
         )
         # check that we stored the access token in the session
-        assert flask.session["test-service_oauth_token"] == {
-            "access_token": "foobar",
-            "scope": ["admin"],
-            "token_type": "bearer",
-        }
+        with client.session_transaction() as sess:
+            assert sess["test-service_oauth_token"] == {
+                "access_token": "foobar",
+                "scope": ["admin"],
+                "token_type": "bearer",
+            }
 
 
 def test_authorized_url_no_state():
@@ -157,9 +156,13 @@ def test_authorized_url_no_state():
         )
         # check that we redirected the client back to login view
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/login/test-service"
+        assert resp.headers["Location"] in (
+            "https://a.b.c/login/test-service",
+            "/login/test-service",
+        )
         # check that there's nothing in the session
-        assert "test-service_oauth_token" not in flask.session
+        with client.session_transaction() as sess:
+            assert "test-service_oauth_token" not in sess
 
 
 @responses.activate
@@ -231,7 +234,7 @@ def test_authorized_url_token_lifetime():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
         # check that we obtained an access token
         assert len(responses.calls) == 1
         request_data = dict(parse_qsl(responses.calls[0].request.body))
@@ -246,7 +249,8 @@ def test_authorized_url_token_lifetime():
             "expires_in": 300,
             "expires_at": 1451649901,
         }
-        assert flask.session["test-service_oauth_token"] == expected_stored_token
+        with client.session_transaction() as sess:
+            assert sess["test-service_oauth_token"] == expected_stored_token
 
 
 def test_return_expired_token(request):
@@ -296,7 +300,7 @@ def test_provider_error():
         )
         # even though there was an error, we should still redirect the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
         # shouldn't even try getting an access token, though
         assert len(responses.calls) == 0
 
@@ -374,7 +378,7 @@ def test_redirect_to():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/blargl"
+        assert resp.headers["Location"] in ("https://a.b.c/blargl", "/blargl")
 
 
 @responses.activate
@@ -413,7 +417,7 @@ def test_redirect_fallback():
         )
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/"
+        assert resp.headers["Location"] in ("https://a.b.c/", "/")
 
 
 def test_authorization_required_decorator_allowed():
@@ -445,7 +449,10 @@ def test_authorization_required_decorator_redirect():
         resp = client.get("/restricted", base_url="https://a.b.c")
         # check that we redirected the client
         assert resp.status_code == 302
-        assert resp.headers["Location"] == "https://a.b.c/login/test-service"
+        assert resp.headers["Location"] in (
+            "https://a.b.c/login/test-service",
+            "/login/test-service",
+        )
 
 
 @requires_blinker
@@ -677,3 +684,28 @@ def test_custom_session_class():
     )
     assert isinstance(bp.session, CustomOAuth2Session)
     assert bp.session.my_attr == "foobar"
+
+
+def test_rule_kwargs():
+    blueprint = OAuth2ConsumerBlueprint(
+        "test-service",
+        __name__,
+        client_id="client_id",
+        client_secret="client_secret",
+        state="random-string",
+        base_url="https://example.com",
+        authorization_url="https://example.com/oauth/authorize",
+        token_url="https://example.com/oauth/access_token",
+        redirect_url="http://mysite.cool/whoa?query=basketball",
+        rule_kwargs={"host": "example2.com"},
+    )
+    app = flask.Flask(__name__)
+    app.secret_key = "secret"
+    app.register_blueprint(blueprint, url_prefix="/login")
+    rules = [
+        rule
+        for rule in app.url_map.iter_rules()
+        if rule.endpoint.startswith("test-service.")
+    ]
+    assert all(rule.host == "example2.com" for rule in rules)
+    assert len(rules) == 2
